ToTelemetry

Trait ToTelemetry 

pub trait ToTelemetry {
    // Required method
    fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Formats a value only through an explicitly approved telemetry representation.

Required Methods

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Writes the representation that may leave the process boundary.

fmt keeps adapters allocation-free so high-volume telemetry paths do not need a parallel “safe String” API just to satisfy backends like tracing.

Implementations on Foreign Types

Source

impl ToTelemetry for IpAddr

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for SocketAddr

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for bool

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for char

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for i8

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for i16

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for i32

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for i64

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for i128

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for isize

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for u8

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for u16

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for u32

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for u64

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for u128

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for usize

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for Ipv4Addr

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for Ipv6Addr

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for SocketAddrV4

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for SocketAddrV6

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<i8>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<i16>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<i32>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<i64>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<i128>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<isize>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<u8>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<u16>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<u32>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<u64>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<u128>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl ToTelemetry for NonZero<usize>

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<K, V> ToTelemetry for BTreeMap<K, V>
where K: ToTelemetry, V: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T> ToTelemetry for Option<T>
where T: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T> ToTelemetry for &T
where T: ToTelemetry + ?Sized,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T> ToTelemetry for [T]
where T: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T> ToTelemetry for Box<T>
where T: ToTelemetry + ?Sized,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T> ToTelemetry for BTreeSet<T>
where T: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T> ToTelemetry for Vec<T>
where T: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T, E> ToTelemetry for Result<T, E>
where T: ToTelemetry, E: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Source

impl<T, const N: usize> ToTelemetry for [T; N]
where T: ToTelemetry,

Source

fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Implementors