pub trait ToTelemetry {
// Required method
fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Expand description
Formats a value only through an explicitly approved telemetry representation.
pub trait ToTelemetry {
// Required method
fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}Formats a value only through an explicitly approved telemetry representation.